@@ -20,15 +20,19 @@ class Sms(webdriver.Remote):
 
     def send_sms(self, phone_number, message):
         """Emulate send SMS event on the connected emulator.
+        Android only.
 
         :Args:
          - phone_number: The phone number of message sender
-         - message: message: The message to send
+         - message: The message to send
 
         :Usage:
             self.driver.send_sms('555-123-4567', 'Hey lol')
         """
         self.execute(Command.SEND_SMS, {'phoneNumber': phone_number, 'message': message})
+        return self
+
+    # pylint: disable=protected-access
 
     def _addCommands(self):
         self.command_executor._commands[Command.SEND_SMS] = \
