@@ -77,3 +77,11 @@ class MobileCommand(object):
     COMPARE_IMAGES = 'compareImages'
     FINGER_PRINT = 'fingerPrint'
     SEND_SMS = 'sendSms'
+    SET_POWER_CAPACITY = 'setPowerCapacity'
+    SET_POWER_AC = 'setPowerAc'
+    SET_GSM_SIGNAL = 'setGsmSignal'
+    MAKE_GSM_CALL = 'makeGsmCall'
+    GET_SYSTEM_BARS = 'getSystemBars'
+    SET_GSM_VOICE = 'setGsmVoice'
+    GET_PERFORMANCE_DATA = 'getPerformanceData'
+    GET_PERFORMANCE_DATA_TYPES = 'getPerformanceDataTypes'
