@@ -32,17 +32,21 @@ from .extensions.applications import Applications
 from .extensions.clipboard import Clipboard
 from .extensions.context import Context
 from .extensions.device_time import DeviceTime
+from .extensions.gsm import Gsm
 from .extensions.images_comparison import ImagesComparison
 from .extensions.ime import IME
 from .extensions.keyboard import Keyboard
 from .extensions.hw_actions import HardwareActions
 from .extensions.location import Location
 from .extensions.network import Network
+from .extensions.performance import Performance
+from .extensions.power import Power
 from .extensions.remote_fs import RemoteFS
 from .extensions.screen_record import ScreenRecord
 from .extensions.search_context import AppiumSearchContext
 from .extensions.settings import Settings
 from .extensions.sms import Sms
+from .extensions.system_bars import SystemBars
 from .mobilecommand import MobileCommand as Command
 from .switch_to import MobileSwitchTo
 from .webelement import WebElement as MobileWebElement
@@ -111,16 +115,20 @@ class WebDriver(
     Clipboard,
     Context,
     DeviceTime,
+    Gsm,
     HardwareActions,
     ImagesComparison,
     IME,
     Keyboard,
     Location,
     Network,
+    Performance,
+    Power,
     RemoteFS,
     ScreenRecord,
     Settings,
-    Sms
+    Sms,
+    SystemBars
 ):
 
     def __init__(self, command_executor='http://127.0.0.1:4444/wd/hub',
